-- Initial DB
SET ANSI_NULLS ON
SET QUOTED_IDENTIFIER ON
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[Constants](
    [Table] [varchar](50) NOT NULL,
    [Column] [varchar](50) NOT NULL,
    [ID] [bigint] NOT NULL,
    [Text] [varchar](250) NULL,
 CONSTRAINT [PK_Constants] PRIMARY KEY CLUSTERED 
(
    [Table] ASC,
    [Column] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[Changelog](
    [Version] [int] NOT NULL,
    [Changes] [text] NULL,
 CONSTRAINT [PK_changelog] PRIMARY KEY CLUSTERED 
(
    [Version] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
CREATE TABLE [dbo].[System](
    [ID] [varchar](50) NOT NULL,
    [Name] [varchar](50) NULL,
    [Port] [int] NULL,
    [Protocol] [varchar](5) NULL,
 CONSTRAINT [PK_System] PRIMARY KEY CLUSTERED 
(
    [ID] ASC
) WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[Log](
    [ID] [uniqueidentifier] NOT NULL,
    [System] [varchar](50) NOT NULL,
    [Time] [datetime] NOT NULL,
    [Text] [text] NOT NULL,
    [Severity] [smallint] NOT NULL,
 CONSTRAINT [PK_Log] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY] TEXTIMAGE_ON [PRIMARY]
GO
CREATE TABLE [dbo].[Group](
    [System] [varchar](50) NOT NULL,
    [ID] [int] NOT NULL,
    [Name] [varchar](255) NULL,
    [Parent] [int] NULL,
 CONSTRAINT [PK_Group] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[Device](
    [System] [varchar](50) NOT NULL,
    [ID] [int] NOT NULL,
    [Name] [varchar](255) NOT NULL,
    [Parent] [int] NULL,
 CONSTRAINT [PK_Device] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[Sensor](
    [System] [varchar](50) NOT NULL,
    [ID] [int] NOT NULL,
    [Name] [varchar](255) NOT NULL,
    [Device] [int] NULL,
    [SensorKind] [varchar](50) NULL,
    [Interval] [int] NULL,
 CONSTRAINT [PK_Sensor] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[Channel](
    [System] [varchar](50) NOT NULL,
    [Sensor] [int] NOT NULL,
    [ID] [int] NOT NULL,
    [Name] [varchar](255) NOT NULL,
    [Mode] [tinyint] NULL,
    [Kind] [varchar](50) NULL,
    [DecimalMode] [tinyint] NULL,
    [DecimalDigits] [tinyint] NULL,
    [SpeedSize] [varchar](50) NULL,
    [SpeedTime] [varchar](50) NULL,
    [VolumeSize] [varchar](50) NULL,
    [IsPrimary] [bit] NOT NULL,
    [CustomUnit] [varchar](50) NULL,
    [ValueLookup] [varchar](100) NULL,
    [LimitLowerError] float NULL,
    [LimitLowerWarning] float NULL,
    [LimitUpperWarning] float NULL,
    [LimitUpperError] float NULL,
 CONSTRAINT [PK_Channel] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [Sensor] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[AbsoluteData](
    [System] [varchar](50) NOT NULL,
    [Sensor] [int] NOT NULL,
    [Channel] [int] NOT NULL,
    [Time] [datetime] NOT NULL,
    [Value] [float] NULL,
    [Date]  AS (CONVERT([date],[Time])) PERSISTED,
 CONSTRAINT [PK_Data] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [Sensor] ASC,
    [Channel] ASC,
    [Time] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[DifferenceData](
    [System] [varchar](50) NOT NULL,
    [Sensor] [int] NOT NULL,
    [Channel] [int] NOT NULL,
    [Time] [datetime] NOT NULL,
    [Volume] [float] NULL,
    [Speed] [float] NULL,
    [Date]  AS (CONVERT([date],[Time])) PERSISTED,
 CONSTRAINT [PK_DifferenceData] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [Sensor] ASC,
    [Channel] ASC,
    [Time] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[SensorStatus](
    [System] [varchar](50) NOT NULL,
    [Sensor] [int] NOT NULL,
    [Time] [datetime] NOT NULL,
    [Status] [int] NOT NULL,
 CONSTRAINT [PK_SensorStatus] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [Sensor] ASC,
    [Time] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[Toplist](
    [System] [varchar](50) NOT NULL,
    [Sensor] [int] NOT NULL,
    [ID] [int] NOT NULL,
    [Name] [varchar](250) NULL,
 CONSTRAINT [PK_Toplist] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [Sensor] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[ToplistIDX](
    [System] [varchar](50) NOT NULL,
    [Sensor] [int] NOT NULL,
    [Toplist] [int] NOT NULL,
    [ID] [int] NOT NULL,
    [Start] [datetime] NOT NULL,
    [End] [datetime] NOT NULL,
    [Interval] [int] NOT NULL,
 CONSTRAINT [PK_ToplistIDX] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [Sensor] ASC,
    [Toplist] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
CREATE TABLE [dbo].[ToplistData](
    [System] [varchar](50) NOT NULL,
    [Sensor] [int] NOT NULL,
    [TopList] [int] NOT NULL,
    [TopListIDX] [int] NOT NULL,
    [ID] [int] NOT NULL,
    [Bytes] [bigint] NULL,
    [SourceIP] [varchar](250) NULL,
    [SourcePort] [int] NULL,
    [DestinationIP] [varchar](250) NULL,
    [DestinationPort] [int] NULL,
    [SourceMAC] [nchar](17) NULL,
    [DestinationMac] [nchar](17) NULL,
    [Protocol] [int] NULL,
    [EtherType] [int] NULL,
    [IPV4TOS] [int] NULL,
    [InboundInterface] [int] NULL,
    [OutboundInterface] [int] NULL,
    [SourceASI] [int] NULL,
    [DestinationASI] [int] NULL,
    [Channel] [int] NULL,
    [IP] [varchar](250) NULL,
    [Port] [int] NULL,
    [MAC] [nchar](17) NULL,
    [Interface] [int] NULL,
    [ASI] [int] NULL,
    [SourceMask] [varchar](250) NULL,
    [DestinationMask] [varchar](250) NULL,
    [NextHop] [varchar](250) NULL,
    [SourceVLAN] [varchar](250) NULL,
    [DestinationVLAN] [varchar](250) NULL,
    [Mask] [varchar](250) NULL,
    [VLAN] [varchar](250) NULL,
    [SenderIP] [varchar](250) NULL,
    [VLANPriority] [int] NULL,
    [VLANIdentifier] [int] NULL,
    [IPV6TrafficClass] [int] NULL,
    [IPV6FlowLabel] [int] NULL,
 CONSTRAINT [PK__ToplistData] PRIMARY KEY CLUSTERED 
(
    [System] ASC,
    [Sensor] ASC,
    [TopList] ASC,
    [TopListIDX] ASC,
    [ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]
GO
SET ANSI_PADDING OFF
-- Log
ALTER TABLE [dbo].[Log] ADD  CONSTRAINT [DF_Log_ID]  DEFAULT (newid()) FOR [ID]
ALTER TABLE [dbo].[Log] ADD  CONSTRAINT [DF_Log_time]  DEFAULT (getdate()) FOR [time]
ALTER TABLE [dbo].[Log]  WITH CHECK ADD  CONSTRAINT [FK_Log_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[Log] CHECK CONSTRAINT [FK_Log_System]
-- Group
ALTER TABLE [dbo].[Group]  WITH CHECK ADD  CONSTRAINT [FK_Group_Group] FOREIGN KEY([System], [Parent])
REFERENCES [dbo].[Group] ([System], [ID])
ALTER TABLE [dbo].[Group] CHECK CONSTRAINT [FK_Group_Group]
ALTER TABLE [dbo].[Group]  WITH CHECK ADD  CONSTRAINT [FK_Group_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[Group] CHECK CONSTRAINT [FK_Group_System]
GO
-- Device
ALTER TABLE [dbo].[Device]  WITH CHECK ADD  CONSTRAINT [FK_Device_Group] FOREIGN KEY([System], [Parent])
REFERENCES [dbo].[Group] ([System], [ID])
ALTER TABLE [dbo].[Device] CHECK CONSTRAINT [FK_Device_Group]
ALTER TABLE [dbo].[Device]  WITH CHECK ADD  CONSTRAINT [FK_Device_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[Device] CHECK CONSTRAINT [FK_Device_System]
GO
-- Sensor
ALTER TABLE [dbo].[Sensor]  WITH CHECK ADD  CONSTRAINT [FK_Sensor_Device] FOREIGN KEY([System], [Device])
REFERENCES [dbo].[Device] ([System], [ID])
ALTER TABLE [dbo].[Sensor] CHECK CONSTRAINT [FK_Sensor_Device]
ALTER TABLE [dbo].[Sensor]  WITH CHECK ADD  CONSTRAINT [FK_Sensor_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[Sensor] CHECK CONSTRAINT [FK_Sensor_System]
GO
-- Channel
ALTER TABLE [dbo].[Channel] ADD  CONSTRAINT [DF_Channel_isPrimary]  DEFAULT ((0)) FOR [isPrimary]
ALTER TABLE [dbo].[Channel]  WITH CHECK ADD  CONSTRAINT [FK_Channel_Sensor] FOREIGN KEY([System], [Sensor])
REFERENCES [dbo].[Sensor] ([System], [ID])
ALTER TABLE [dbo].[Channel] CHECK CONSTRAINT [FK_Channel_Sensor]
ALTER TABLE [dbo].[Channel]  WITH CHECK ADD  CONSTRAINT [FK_Channel_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[Channel] CHECK CONSTRAINT [FK_Channel_System]
GO
-- AbsoluteData
ALTER TABLE [dbo].[AbsoluteData]  WITH CHECK ADD  CONSTRAINT [FK_AbsoluteData_Channel] FOREIGN KEY([System], [Sensor], [Channel])
REFERENCES [dbo].[Channel] ([System], [Sensor], [ID])
ALTER TABLE [dbo].[AbsoluteData] CHECK CONSTRAINT [FK_AbsoluteData_Channel]
ALTER TABLE [dbo].[AbsoluteData]  WITH CHECK ADD  CONSTRAINT [FK_AbsoluteData_Sensor] FOREIGN KEY([System], [Sensor])
REFERENCES [dbo].[Sensor] ([System], [ID])
ALTER TABLE [dbo].[AbsoluteData] CHECK CONSTRAINT [FK_AbsoluteData_Sensor]
ALTER TABLE [dbo].[AbsoluteData]  WITH CHECK ADD  CONSTRAINT [FK_AbsoluteData_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[AbsoluteData] CHECK CONSTRAINT [FK_AbsoluteData_System]
GO
-- DifferenceData
ALTER TABLE [dbo].[DifferenceData]  WITH CHECK ADD  CONSTRAINT [FK_DifferenceData_Channel] FOREIGN KEY([System], [Sensor], [Channel])
REFERENCES [dbo].[Channel] ([System], [Sensor], [ID])
ALTER TABLE [dbo].[DifferenceData] CHECK CONSTRAINT [FK_DifferenceData_Channel]
ALTER TABLE [dbo].[DifferenceData]  WITH CHECK ADD  CONSTRAINT [FK_DifferenceData_Sensor] FOREIGN KEY([System], [Sensor])
REFERENCES [dbo].[Sensor] ([System], [ID])
ALTER TABLE [dbo].[DifferenceData] CHECK CONSTRAINT [FK_DifferenceData_Sensor]
ALTER TABLE [dbo].[DifferenceData]  WITH CHECK ADD  CONSTRAINT [FK_DifferenceData_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[DifferenceData] CHECK CONSTRAINT [FK_DifferenceData_System]
GO
ALTER TABLE [dbo].[SensorStatus]  WITH CHECK ADD  CONSTRAINT [FK_SensorStatus_Sensor] FOREIGN KEY([System], [Sensor])
REFERENCES [dbo].[Sensor] ([System], [ID])
ALTER TABLE [dbo].[SensorStatus] CHECK CONSTRAINT [FK_SensorStatus_Sensor]
ALTER TABLE [dbo].[SensorStatus]  WITH CHECK ADD  CONSTRAINT [FK_SensorStatus_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[SensorStatus] CHECK CONSTRAINT [FK_SensorStatus_System]
GO
ALTER TABLE [dbo].[Toplist]  WITH CHECK ADD  CONSTRAINT [FK_Toplist_Sensor] FOREIGN KEY([System], [Sensor])
REFERENCES [dbo].[Sensor] ([System], [ID])
ALTER TABLE [dbo].[Toplist] CHECK CONSTRAINT [FK_Toplist_Sensor]
ALTER TABLE [dbo].[Toplist]  WITH CHECK ADD  CONSTRAINT [FK_Toplist_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[Toplist] CHECK CONSTRAINT [FK_Toplist_System]
GO
ALTER TABLE [dbo].[ToplistIDX]  WITH CHECK ADD  CONSTRAINT [FK_ToplistIDX_Sensor] FOREIGN KEY([System], [Sensor])
REFERENCES [dbo].[Sensor] ([System], [ID])
ALTER TABLE [dbo].[ToplistIDX] CHECK CONSTRAINT [FK_ToplistIDX_Sensor]
ALTER TABLE [dbo].[ToplistIDX]  WITH CHECK ADD  CONSTRAINT [FK_ToplistIDX_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[ToplistIDX] CHECK CONSTRAINT [FK_ToplistIDX_System]
ALTER TABLE [dbo].[ToplistIDX]  WITH CHECK ADD  CONSTRAINT [FK_ToplistIDX_Toplist] FOREIGN KEY([System], [Sensor], [Toplist])
REFERENCES [dbo].[Toplist] ([System], [Sensor], [ID])
ALTER TABLE [dbo].[ToplistIDX] CHECK CONSTRAINT [FK_ToplistIDX_Toplist]
GO
ALTER TABLE [dbo].[ToplistData]  WITH CHECK ADD  CONSTRAINT [FK_ToplistData_Sensor] FOREIGN KEY([System], [Sensor])
REFERENCES [dbo].[Sensor] ([System], [ID])
ALTER TABLE [dbo].[ToplistData] CHECK CONSTRAINT [FK_ToplistData_Sensor]
ALTER TABLE [dbo].[ToplistData]  WITH CHECK ADD  CONSTRAINT [FK_ToplistData_System] FOREIGN KEY([System])
REFERENCES [dbo].[System] ([ID])
ALTER TABLE [dbo].[ToplistData] CHECK CONSTRAINT [FK_ToplistData_System]
ALTER TABLE [dbo].[ToplistData]  WITH CHECK ADD  CONSTRAINT [FK_ToplistData_Toplist] FOREIGN KEY([System], [Sensor], [TopList])
REFERENCES [dbo].[Toplist] ([System], [Sensor], [ID])
ALTER TABLE [dbo].[ToplistData] CHECK CONSTRAINT [FK_ToplistData_Toplist]
ALTER TABLE [dbo].[ToplistData]  WITH CHECK ADD  CONSTRAINT [FK_ToplistData_ToplistIDX] FOREIGN KEY([System], [Sensor], [TopList], [TopListIDX])
REFERENCES [dbo].[ToplistIDX] ([System], [Sensor], [Toplist], [ID])
ON DELETE CASCADE
ALTER TABLE [dbo].[ToplistData] CHECK CONSTRAINT [FK_ToplistData_ToplistIDX]
GO
INSERT INTO [dbo].[Constants] ([table], [column], [id], [text])
SELECT 'SensorStatus', 'Status', 601, 'Unknown'
UNION ALL SELECT 'SensorStatus', 'Status', 602, 'Resuming'
UNION ALL SELECT 'SensorStatus', 'Status', 603, 'Paused'
UNION ALL SELECT 'SensorStatus', 'Status', 604, 'Paused By User'
UNION ALL SELECT 'SensorStatus', 'Status', 605, 'Paused By Dependency'
UNION ALL SELECT 'SensorStatus', 'Status', 606, 'Paused By Schedule'
UNION ALL SELECT 'SensorStatus', 'Status', 607, 'Up'
UNION ALL SELECT 'SensorStatus', 'Status', 608, 'Down'
UNION ALL SELECT 'SensorStatus', 'Status', 609, 'Warning'
UNION ALL SELECT 'SensorStatus', 'Status', 610, 'Unusual'
UNION ALL SELECT 'SensorStatus', 'Status', 611, 'Ok'
UNION ALL SELECT 'SensorStatus', 'Status', 612, 'Probe Connected'
UNION ALL SELECT 'SensorStatus', 'Status', 613, 'Probe Disconnected'
UNION ALL SELECT 'SensorStatus', 'Status', 614, 'Probe Info'
UNION ALL SELECT 'SensorStatus', 'Status', 615, 'Paused License'
UNION ALL SELECT 'SensorStatus', 'Status', 616, 'No Probe'
UNION ALL SELECT 'SensorStatus', 'Status', 617, 'None'
UNION ALL SELECT 'SensorStatus', 'Status', 618, 'Active'
UNION ALL SELECT 'SensorStatus', 'Status', 619, 'Down Acknowledged'
UNION ALL SELECT 'SensorStatus', 'Status', 620, 'Down Partial'
GO
INSERT INTO [dbo].[Changelog] ([Version], [changes]) VALUES (1, 'Initial DB')
